@@ -12,18 +12,13 @@ if sys.platform[0:3] == "win" or sys.platform == "darwin":
     import matplotlib
     matplotlib.use('TkAgg')
 import matplotlib.pyplot as plt
-import matplotlib.ticker as mtick
 import matplotlib.cm as cm
-import matplotlib.colors as mpl_col
-from matplotlib.ticker import StrMethodFormatter
 import copy
 import os
 import sys
 
-from . import utils as ut
 from . import gui
 
-
 # Generic ac magnetometer file header names
 HEADERS_GENERIC = [
     "field",
@@ -373,7 +368,6 @@ class Model(ABC):
                 label=_label
             )
 
-        ax1.yaxis.set_major_formatter(StrMethodFormatter('{x:.2f}'))
         ax1.legend(
             loc=0, fontsize='small', numpoints=1, ncol=2, frameon=False
         )
@@ -611,10 +605,12 @@ class Model(ABC):
             model.fit_temperature for model in models if model.fit_status
         ]
 
+        n_temps = len(fitted_temps)
+
         ratio = np.linspace(0, 1, np.sum(
             [model.fit_status for model in models])
         )
-        colors = cm.get_cmap('coolwarm', len(fitted_temps))
+        colors = cm.get_cmap('coolwarm', n_temps)
 
         # Experimental data
         count = -1
@@ -653,50 +649,12 @@ class Model(ABC):
                 color=colors(ratio[count]),
                 lw=1
             )
-        
-        # Find min and max fitted temperatures
-        min_T = round(min(fitted_temps), 2)
-        max_T = round(max(fitted_temps), 2)
 
-        # Make colourbar
-        # Norm creates an indexing for the colourmap values
-        # i.e. what do the start and end correspond to
-        norm = mpl_col.BoundaryNorm(
-            np.linspace(min_T-0.000001, max_T+0.000001, len(fitted_temps)+1),
-            ncolors=colors.N
-        )
-
-        # Scalar mappable converts colourmap numbers into an image of colours
-        sm = cm.ScalarMappable(cmap=colors, norm=norm)
-
-        colourbar_ticks = ut.get_temp_colourbar_ticks(fitted_temps)
-
-        cbar = fig.colorbar(
-            sm,
-            ticks=colourbar_ticks,
-            orientation='horizontal',
-            format='%.1f',
-            cax=ax1
-        )
-
-        ax1.set_xticklabels(
-            colourbar_ticks,
-            rotation=45,
-            fontsize='smaller'
-        )
-
-        ax1.minorticks_off()
-
-        # Set colourbar label - technically title - above bar
-        cbar.ax.set_title('T (K)', fontsize='smaller')
+        gui.create_ac_temp_colorbar(ax1, fig, fitted_temps, colors)
 
         # Put the x-labels of the colourbar on top
         ax1.xaxis.set_ticks_position('top')
 
-        # Sets float formatting with two decimal numbers
-        for axis in [ax2.xaxis, ax2.yaxis]:
-            axis.set_major_formatter(mtick.FormatStrFormatter('%.2f'))
-
         # Remove frames
         ax2.spines["top"].set_visible(False)
         ax2.spines["right"].set_visible(False)
@@ -770,7 +728,6 @@ class Model(ABC):
         fig.subplots_adjust(hspace=.5, wspace=.02)
 
         ax1.xaxis.set_ticks_position('top')
-        ax2.xaxis.set_major_formatter(mtick.FormatStrFormatter('%.1f'))
 
         fitted_temps = [
             model.fit_temperature for model in models if model.fit_status
@@ -779,7 +736,9 @@ class Model(ABC):
         ratio = np.linspace(0, 1, np.sum(
             [model.fit_status for model in models])
         )
-        colors = cm.get_cmap('coolwarm', len(fitted_temps))
+
+        n_temps = len(fitted_temps)
+        colors = cm.get_cmap('coolwarm', n_temps)
 
         # Experimental data
         count = -1
@@ -806,7 +765,7 @@ class Model(ABC):
                 'o',
                 markersize=4,
                 fillstyle='none',
-                label='{} K'.format(model.fit_temperature),
+                label='{:.2f} K'.format(model.fit_temperature),
                 color=colors(ratio[count])
             )
             ax2.semilogx(
@@ -823,7 +782,7 @@ class Model(ABC):
                 'o',
                 markersize=4,
                 fillstyle='none',
-                label='{} K'.format(model.fit_temperature),
+                label='{:.2f} K'.format(model.fit_temperature),
                 color=colors(ratio[count])
             )
             ax3.semilogx(
@@ -834,42 +793,10 @@ class Model(ABC):
                 lw=1
             )
 
-        # Do not share ax3 as it is linear and these are log
+        # Do not share yax as it is linear and these are log
         ax3.get_shared_x_axes().join(ax2, ax3)
 
-        # Find min and max fitted temperatures
-        min_T = round(min(fitted_temps), 2)
-        max_T = round(max(fitted_temps), 2)
-
-        # Make colourbar
-        # Norm creates an indexing for the colourmap values
-        # i.e. what do the start and end correspond to
-        norm = mpl_col.BoundaryNorm(
-            np.linspace(min_T-0.000001, max_T+0.000001, len(fitted_temps)+1),
-            ncolors=colors.N
-        )
-        # Scalar mappable converts colourmap numbers into an image of colours
-        sm = cm.ScalarMappable(cmap=colors, norm=norm)
-
-        colourbar_ticks = ut.get_temp_colourbar_ticks(fitted_temps)
-
-        cbar = fig.colorbar(
-            sm,
-            ticks=colourbar_ticks,
-            orientation='horizontal',
-            format='%.1f',
-            cax=ax1
-        )
-
-        ax1.set_xticklabels(
-            colourbar_ticks,
-            rotation=45,
-            fontsize='smaller'
-        )
-
-        ax1.minorticks_off()
-
-        cbar.ax.set_title('T (K)', fontsize='smaller')
+        gui.create_ac_temp_colorbar(ax1, fig, fitted_temps, colors)
 
         ax2.set_xticklabels([])
         ax2.set_ylabel(r'$\chi^{,}$  (cm$^{3}$mol$^{-1}$)')
@@ -878,7 +805,6 @@ class Model(ABC):
             axis.spines["top"].set_visible(False)
             axis.spines["right"].set_visible(False)
 
-        ax3.xaxis.set_major_formatter(mtick.FormatStrFormatter('%.1f'))
         # Get rid of the x-labels of real susceptibility
         ax2.set_xticklabels([])
         ax2.set_ylabel(r'$\chi^{,}$  (cm$^{3}$mol$^{-1}$)')
@@ -1528,7 +1454,7 @@ class TwoMaximaModel(Model):
         if verbose:
             print(
                 '\nThe initial guesses are',
-                '\ntau_1 = {}\ndelta_chi_1 = {}\nalpha_1 = {}\ntau_2 = {}\ndelta_chi_2 = {}\nalpha_2 = {}\nchi_total = {}'.format(
+                '\ntau_1 = {}\ndelta_chi_1 = {}\nalpha_1 = {}\ntau_2 = {}\ndelta_chi_2 = {}\nalpha_2 = {}\nchi_total = {}'.format( # noqa
                     *self.initial_params
                 )
             )
@@ -1826,7 +1752,7 @@ class Experiment():
     def from_measurements(cls,
                           measurements: list[Measurement],
                           temp_thresh: float = 0.1,
-                          field_thresh: float = 1e-8) -> list[list['Experiment']]:
+                          field_thresh: float = 1e-8) -> list[list['Experiment']]: # noqa
         """
         Creates list of Experiment objecst from a list of individual
         Measurement objects. Experiments are defined as a set of measurements
@@ -1974,104 +1900,54 @@ class Experiment():
         None
         """
 
-        fig, (ax1, ax2, ax3) = plt.subplots(
-            3,
+        fig, (ax1, ax2) = plt.subplots(
+            2,
             1,
             sharex='none',
             sharey='none',
             figsize=(6.5, 4.5),
-            gridspec_kw={"height_ratios": [0.05, 1, 1]},
             num='Raw AC susceptibility'
         )  # 8.27, 11.69 A4
         fig.subplots_adjust(hspace=.5, wspace=.02)
 
-        ax1.xaxis.set_ticks_position('top')
-        ax2.xaxis.set_major_formatter(mtick.FormatStrFormatter('%.1f'))
-
-        # Find min and max fitted temperatures
-        fitted_temps = [
-            experiment.temperatures[0] for experiment in experiments
-        ]
-
-        ratio = np.linspace(0, 1, len(experiments))
-        colors = cm.get_cmap('coolwarm', len(fitted_temps))
-
         # Experimental data
-        count = -1
         for experiment in experiments:
 
-            count += 1
-
             # Real
-            ax2.semilogx(
+            ax1.semilogx(
                 experiment.ac_freq*2*np.pi,
                 experiment.sus_re,
-                'o',
+                '-o',
                 markersize=4,
                 fillstyle='none',
-                label='{} K'.format(experiment.temperatures[0]),
-                color=colors(ratio[count])
+                label='{:.2f} K'.format(experiment.temperatures[0])
             )
             # Imaginary
-            ax3.semilogx(
+            ax2.semilogx(
                 experiment.ac_freq*2*np.pi,
                 experiment.sus_im,
-                'o',
+                '-o',
                 markersize=4,
                 fillstyle='none',
-                label='{} K'.format(experiment.temperatures[0]),
-                color=colors(ratio[count])
+                label='{:.2f} K'.format(experiment.temperatures[0])
             )
 
-        # Do not share ax3 as it is linear and these are log
-        ax3.get_shared_x_axes().join(ax2, ax3)
+        ax2.get_shared_x_axes().join(ax1, ax2)
 
-        min_T = round(min(fitted_temps), 2)
-        max_T = round(max(fitted_temps), 2)
-
-        # Make colourbar
-        # Norm creates an indexing for the colourmap values
-        # i.e. what do the start and end correspond to
-        norm = mpl_col.BoundaryNorm(
-            np.linspace(min_T-0.000001, max_T+0.000001, len(fitted_temps)+1),
-            ncolors=colors.N
-        )
-        # Scalar mappable converts colourmap numbers into an image of colours
-        sm = cm.ScalarMappable(cmap=colors, norm=norm)
-
-        colourbar_ticks = ut.get_temp_colourbar_ticks(fitted_temps)
-
-        cbar = fig.colorbar(
-            sm,
-            ticks=colourbar_ticks,
-            orientation='horizontal',
-            format='%.1f',
-            cax=ax1
-        )
-
-        ax1.set_xticklabels(
-            colourbar_ticks,
-            rotation=45,
-            fontsize='smaller'
-        )
-
-        ax1.minorticks_off()
-
-        cbar.ax.set_title('T (K)', fontsize='smaller')
-
-        ax2.set_xticklabels([])
-        ax2.set_ylabel(r'$\chi^{,}$  (cm$^{3}$mol$^{-1}$)')
+        ax1.set_xticklabels([])
+        ax1.set_ylabel(r'$\chi^{,}$  (cm$^{3}$mol$^{-1}$)')
         # Get rid of the frames of susceptibility plots
-        for axis in [ax2, ax3]:
+        for axis in [ax1, ax2]:
             axis.spines["top"].set_visible(False)
             axis.spines["right"].set_visible(False)
 
-        ax3.xaxis.set_major_formatter(mtick.FormatStrFormatter('%.1f'))
         # Get rid of the x-labels of real susceptibility
-        ax2.set_xticklabels([])
-        ax2.set_ylabel(r'$\chi^{,}$  (cm$^{3}$mol$^{-1}$)')
-        ax3.set_xlabel('Wave Frequency (Hz)')
-        ax3.set_ylabel(r'$\chi^{,,}$ (cm$^{3}$mol$^{-1}$)')
+        ax1.set_xticklabels([])
+        ax1.set_ylabel(r'$\chi^{,}$  (cm$^{3}$mol$^{-1}$)')
+        ax2.set_xlabel('Wave Frequency (Hz)')
+        ax2.set_ylabel(r'$\chi^{,,}$ (cm$^{3}$mol$^{-1}$)')
+
+        fig.legend(frameon=False)
 
         if save:
 
@@ -2115,89 +1991,38 @@ class Experiment():
         None
         """
 
-        fig, (ax1, ax2) = plt.subplots(
-            2,
+        fig, ax1 = plt.subplots(
+            1,
             1,
             sharex='none',
             sharey='none',
             figsize=(5.1, 4.8),
-            gridspec_kw={"height_ratios": [0.03, 0.9]},
             num='Raw Cole-Cole'
         )
         fig.subplots_adjust(hspace=.02, wspace=.02)
 
-        fitted_temps = [
-            experiment.temperatures[0] for experiment in experiments
-        ]
-
-        ratio = np.linspace(0, 1, len(experiments))
-        colors = cm.get_cmap('coolwarm', len(fitted_temps))
-
         # Experimental data
         for eit, experiment in enumerate(experiments):
 
             # Plot Cole-Cole
-            ax2.plot(
+            ax1.plot(
                 experiment.sus_re,
                 experiment.sus_im,
-                'o',
+                '-o',
                 markersize=4,
                 fillstyle='none',
                 label="{:.2f} K".format(experiment.temperatures[0]),
-                color=colors(ratio[eit])
             )
 
-        # Find min and max fitted temperatures
-
-        min_T = round(min(fitted_temps), 2)
-        max_T = round(max(fitted_temps), 2)
-
-        # Make colourbar
-        # Norm creates an indexing for the colourmap values
-        # i.e. what do the start and end correspond to
-        norm = mpl_col.BoundaryNorm(
-            np.linspace(min_T-0.000001, max_T+0.000001, len(fitted_temps)+1),
-            ncolors=colors.N
-        )
-
-        # Scalar mappable converts colourmap numbers into an image of colours
-        sm = cm.ScalarMappable(cmap=colors, norm=norm)
-
-        colourbar_ticks = ut.get_temp_colourbar_ticks(fitted_temps)
-
-        cbar = fig.colorbar(
-            sm,
-            ticks=colourbar_ticks,
-            orientation='horizontal',
-            format='%.1f',
-            cax=ax1
-        )
-
-        ax1.set_xticklabels(
-            colourbar_ticks,
-            rotation=45,
-            fontsize='smaller'
-        )
-
-        ax1.minorticks_off()
-
-        # Set colourbar label - technically title - above bar
-        cbar.ax.set_title('T (K)', fontsize='smaller')
-
-        # Put the x-labels of the colourbar on top
-        ax1.xaxis.set_ticks_position('top')
-
-        # Sets float formatting with two decimal numbers
-        for axis in [ax2.xaxis, ax2.yaxis]:
-            axis.set_major_formatter(mtick.FormatStrFormatter('%.2f'))
+        fig.legend(frameon=False)
 
         # Remove frames
-        ax2.spines["top"].set_visible(False)
-        ax2.spines["right"].set_visible(False)
+        ax1.spines["top"].set_visible(False)
+        ax1.spines["right"].set_visible(False)
 
         # Set labels for the axes
-        ax2.set_xlabel(r'$\chi^{,}$  (cm$^{3}$mol$^{-1}$)')
-        ax2.set_ylabel(r'$\chi^{,,}$ (cm$^{3}$mol$^{-1}$)')
+        ax1.set_xlabel(r'$\chi^{,}$  (cm$^{3}$mol$^{-1}$)')
+        ax1.set_ylabel(r'$\chi^{,,}$ (cm$^{3}$mol$^{-1}$)')
 
         fig.tight_layout()
 
@@ -2398,7 +2223,7 @@ def interactive_t_select(experiments: list[Experiment]):
         axs = np.delete(axs, -1)
 
     for ax in axs:
-        ax.set_facecolor("Green")
+        ax.set_facecolor("White")
 
     # Store object, one per temperature
     stores = [Toggle(temp) for temp in unique_temps]
@@ -2449,7 +2274,7 @@ class Toggle():
 
     def __init__(self, temperature):
 
-        self.on = True
+        self.on = False
         self.temperature = temperature
 
     def switch(self, ax):
