@@ -15,6 +15,7 @@ import warnings
 warnings.filterwarnings("ignore", ".*GUI is implemented.*")
 warnings.filterwarnings("ignore", "invalid value encountered in power")
 warnings.filterwarnings("ignore", 'invalid value encountered in log10')
+warnings.filterwarnings("ignore", 'invalid value encountered in divide')
 
 
 def ac_mode_func(args):
@@ -93,7 +94,9 @@ def ac_mode_func(args):
                         experiment.raw_temperatures
                     )
                 )
-                print('{} Frequencies: {}\n'.format(len(experiment.ac_freq), experiment.ac_freq))
+                print('{} Frequencies: {}\n'.format(
+                    len(experiment.ac_freq), experiment.ac_freq)
+                )
 
     # Manual selection of temperatures to fit
     if args.select_T:
@@ -238,13 +241,8 @@ def ac_mode_func(args):
         if len(tau) == 1:
             continue
 
-        # Select the model function to be used.
-        # Set field to zero so Direct is never activated in AC module.
-
-        if np.abs(dc_field) < args.zf_cutoff:
-            dc_field = 0.
         relax.select_model_rates(
-            rxp, temperature, 1./tau, dc_field, _process='tau_vs_T'
+            rxp, temperature, 1./tau, 0., _process='tau_vs_T'
         )
 
     return
@@ -587,13 +585,6 @@ def read_args(arg_list=None):
         default=1e-8,
         help='Threshold used to discriminate between DC Fields, default 1e-8 Oe' # noqa
     )
-    ac_parser.add_argument(
-        '--zf_cutoff',
-        metavar='<float>',
-        type=float,
-        default=5,
-        help='DC Field with smaller absolute valuesthan this will be considered to be zero, default 5 Oe' # noqa
-    )
     ac_parser.add_argument(
         '--select_T',
         action='store_true',
@@ -642,7 +633,6 @@ def read_args(arg_list=None):
             help=""
         )
 
-
     # Waveform
     description_Waveform = """
     Extract AC susceptibilities from waveform data
