@@ -495,47 +495,3 @@ class UserConfig():
             os.mkdir(self.results_dir)
 
         return
-
-
-def get_temp_colourbar_ticks(temperatures: list[float]) -> list[float]:
-    """
-    Creates ticks for a temperature colourbar
-    If there are fewer than 9 data points, show all from 1st to last all temp in temperatures.
-
-    If there are between 9 and 17, slice every 3 and 4 points depending on even-odd.
-
-    If there are more than 17, slice every 5 and 6 points depending on even-odd.
-
-    Parameters
-    ----------
-    temperatures : list
-        Floats of temperatures in Kelvin
-
-    Returns
-    -------
-    list
-        Colourbar tick positions
-    """ # noqa
-
-    n_temps = len(temperatures)
-
-    if n_temps <= 8:
-        colourbar_ticks = [round(temp, 2) for temp in temperatures]
-    elif 9 <= n_temps <= 17:
-        if n_temps % 2 == 0:
-            colourbar_ticks = [round(temp, 2) for temp in temperatures][::3]
-            colourbar_ticks += [
-                [round(temp, 2) for temp in temperatures][-1]
-            ]
-        elif n_temps % 2 != 0:
-            colourbar_ticks = [round(temp, 2) for temp in temperatures][::4]
-    else:
-        if n_temps % 2 == 0:
-            colourbar_ticks = [round(temp, 2) for temp in temperatures][::5]
-            colourbar_ticks += [
-                [round(temp, 2) for temp in temperatures][-1]
-            ]
-        elif n_temps % 2 != 0:
-            colourbar_ticks = [round(temp, 2) for temp in temperatures][::6]
-
-    return colourbar_ticks
